r: A free software environment for statistical computing and graphics
=====================================================================

Description
-----------

R is a language and environment for statistical computing and graphics.
It is a GNU project which is similar to the S language and environment
which was developed at Bell Laboratories (formerly AT&T, now Lucent
Technologies) by John Chambers and colleagues. R can be considered as a
different implementation of S. There are some important differences, but
much code written for S runs unaltered under R.

(taken from http://www.r-project.org/)

License
-------

-  GPL v2 or GPL v3


Upstream Contact
----------------

-  https://www.r-project.org
-  R mailing list, #R in IRC

Dependencies
------------

-  GNU patch
-  iconv
-  Readline
-  BLAS/LAPACK
-  xz
-  pcre
-  curl
-  https-capable SSL
